# Who maintains pins

The pins-python package was is currently maintained by Isabel Zimmerman <isabel.zimmerman@posit.co>. [Posit Software, PBC](https://posit.co/products/open-source/) is a copyright holder and funder of this package.

Several individuals in the community have taken an active role in helping to maintain this package and submit fixes. Those individuals are shown in the git changelog.
